
###---------------------------------------------------------------------------------------------------------------------------
### Run analysis - Get AUC & p-values
###--------------------------------------------------------------------------------------------------------------------------

df <- read.csv("./DATA-raw.csv")

# AUC ------------------------------------------------------------------------------------
RES <- sapply(as.character(unique(df$Type)[1:4]), function(Y){
  
  df.sub <- dplyr::filter(df, Type == Y)
  print(Y)

  res <- sapply(X = colnames(df.sub[,3:9]), function(X){
      
      # Get value for each imaging type / week
      pred <- c(df.sub$baseline, df.sub[,X])
      # Baseline no cancer / Assuption yes after
      class <- c(rep(0,5), rep(1, 5))
    
      # compute AUC (pROC)
      aucs <- roc(class, pred)
      value <- ifelse(aucs$auc <0.5, 1 - aucs$auc, aucs$auc)

      return(value)})
  
  return(res)})


# Run for PET Scan (update from 02/02/18) - missing first weeks which require to compute it separatly
df.sub <- dplyr::filter(df, Type == "PET scan")

res <- sapply(X = colnames(df.sub[,4:9]), function(X){ # Missing first week
  
  # Get value for each imaging type / week
  pred <- c(df.sub$baseline, df.sub[,X])
  # Baseline no cancer / Assuption yes after
  
  class <- c(rep(0,5), rep(1, 5))
  aucs <- roc(class, pred)
  value <- ifelse(aucs$auc <0.5, 1 - aucs$auc, aucs$auc)
  
  return(value)})

# Combine data, assign NA to first week
RES <- as.data.frame(RES)
RES$'PET scan' <- as.numeric(c(NA, as.numeric(res)))
RES$Time <- rownames(RES)


# P-values ---------------------------------------------------------------------------
RES.p <- sapply(as.character(unique(df$Type)[1:4]), function(Y){
  
  df.sub <- dplyr::filter(df, Type == Y)
  print(Y)
  
  res <- sapply(X = colnames(df.sub[,3:9]), function(X){
    
    # Get value for each imaging type / week
    pred <- c(df.sub$baseline, df.sub[,X])
    # Baseline no cancer / Assuption yes after
    class <- c(rep(0,5), rep(1, 5))
    
    # Wilcoxon
    p <- wilcox.test(pred ~ class)$p.value
    
    return(p)
    
  })
  
  return(res)

})


# Run for PET Scan (update from 02/02/18)
df.sub <- dplyr::filter(df, Type == "PET scan")

res <- sapply(X = colnames(df.sub[,4:9]), function(X){ # Missing first week
  
  # Get value for each imaging type / week
  pred <- c(df.sub$baseline, df.sub[,X])
  # Baseline no cancer / Assuption yes after
  class <- c(rep(0,5), rep(1, 5))
  p <- wilcox.test(pred ~ class)$p.value
  
  return(p)})


# Combine data, assign NA to first week
RES.p <- as.data.frame(RES.p)
RES.p$'PET scan' <- as.numeric(c(NA, as.numeric(res)))
RES.p$Time <- rownames(RES.p)


# Save Values
write.csv(x = RES, file = "./AUCs.csv")
write.csv(x = RES.p, file = "./Pvalues.csv")


# Heatmap ----------------------------------------------------------------------------

# Format data before plot
df.plot <- dplyr::inner_join(x = melt(RES, varnames = c("Time", "Type"), value.name = "AUC"), 
                        y = melt(RES.p, varnames = c("Time", "Type"), value.name = "p.value"))

df.plot$variable <- factor(x = df.plot$variable, levels = c("CT scan", "BLI scan", "Light chain test", "MRI scan", 'PET scan'))
df.plot$Time <- factor(x = df.plot$Time, levels = rev(as.character(unique(df.plot$Time))))


# plot
pdf(file = "./Heatmap.pdf", width = 6, height = 6); print(

ggplot(data = df.plot, mapping = aes(x = variable, y = Time, fill = AUC)) +
  
  geom_tile(colour = "black", size = 0.3) +
  
  geom_text(data = filter(df.plot, p.value < 0.05), label = "*", size=8, vjust = 0.78, color = "black") +
  
  scale_fill_gradient2(low = "white", high = "#377EB8",
                       midpoint = 0.7, limit = c(0.5,1), space = "Lab") +
  
  theme_minimal() + 
  
  theme(axis.title.x=element_blank(), 
        axis.title.y=element_blank())

); dev.off()